==> alloy-ui-3.0.1.jar: META-INF/resources/webjars/alloy-ui/3.0.1/src/aui-modal/HISTORY.md <==
# AUI Modal

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-modal).

## @VERSION@

* [AUI-1767](https://issues.liferay.com/browse/AUI-1767) Realign modal when window is resized

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1549](https://issues.liferay.com/browse/AUI-1549) Error in widget-modality.js
* [AUI-1306](https://issues.liferay.com/browse/AUI-1306) Make aui-modal responsive
* [AUI-1336](https://issues.liferay.com/browse/AUI-1336) Scrolling content in Modal on mobile devices can scroll parent page
* [AUI-1368](https://issues.liferay.com/browse/AUI-1368) Modal can't be hidden if destroyOnHide is false
* [AUI-1315](https://issues.liferay.com/browse/AUI-1315) Modal size is increased automatically when re-size handler is clicked but not dragged
* [AUI-1338](https://issues.liferay.com/browse/AUI-1338) Modal footer have erroneous margin inherited from bootstrap 3
* [AUI-1287](https://issues.liferay.com/browse/AUI-1287) Wrong css formatting when running "grunt format"
* [AUI-1174](https://issues.liferay.com/browse/AUI-1174) Validate source code with JSHint
* [AUI-1284](https://issues.liferay.com/browse/AUI-1284) Use cssClass attribute from WidgetCssClass instead of separated atributes for CSS class names in Button
* [AUI-1098](https://issues.liferay.com/browse/AUI-1098) Upgrade to Bootstrap 3
* [AUI-1267](https://issues.liferay.com/browse/AUI-1267) Move CSS classes from Alloy Bootstrap to AlloyUI
* [AUI-1253](https://issues.liferay.com/browse/AUI-1253) Fix modal header buttons pushing the header content down
* [AUI-1248](https://issues.liferay.com/browse/AUI-1248) Allow users to request buttons to not have the .btn-default class on Bootstrap 3
* [AUI-1238](https://issues.liferay.com/browse/AUI-1238) Migrate Modal markup to Bootstrap 3

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1306](https://issues.liferay.com/browse/AUI-1306) Make aui-modal responsive
* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants
* [AUI-1107](https://issues.liferay.com/browse/AUI-1107) Listeners after visibleChange are not executed with modal.destroyOnHide enabled

==> alloy-ui-3.0.2.jar: META-INF/resources/webjars/alloy-ui/3.0.2/src/aui-modal/HISTORY.md <==
# AUI Modal

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-modal).

## @VERSION@

* [AUI-2028](https://issues.liferay.com/browse/AUI-2028) AUI Modal Component should inherit CSS rules from Bootstrap therefore the markup must be as similar as possible.

## [3.0.1](https://github.com/liferay/alloy-ui/releases/tag/3.0.1)

* [AUI-1767](https://issues.liferay.com/browse/AUI-1767) Realign modal when window is resized

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1549](https://issues.liferay.com/browse/AUI-1549) Error in widget-modality.js
* [AUI-1306](https://issues.liferay.com/browse/AUI-1306) Make aui-modal responsive
* [AUI-1336](https://issues.liferay.com/browse/AUI-1336) Scrolling content in Modal on mobile devices can scroll parent page
* [AUI-1368](https://issues.liferay.com/browse/AUI-1368) Modal can't be hidden if destroyOnHide is false
* [AUI-1315](https://issues.liferay.com/browse/AUI-1315) Modal size is increased automatically when re-size handler is clicked but not dragged
* [AUI-1338](https://issues.liferay.com/browse/AUI-1338) Modal footer have erroneous margin inherited from bootstrap 3
* [AUI-1287](https://issues.liferay.com/browse/AUI-1287) Wrong css formatting when running "grunt format"
* [AUI-1174](https://issues.liferay.com/browse/AUI-1174) Validate source code with JSHint
* [AUI-1284](https://issues.liferay.com/browse/AUI-1284) Use cssClass attribute from WidgetCssClass instead of separated atributes for CSS class names in Button
* [AUI-1098](https://issues.liferay.com/browse/AUI-1098) Upgrade to Bootstrap 3
* [AUI-1267](https://issues.liferay.com/browse/AUI-1267) Move CSS classes from Alloy Bootstrap to AlloyUI
* [AUI-1253](https://issues.liferay.com/browse/AUI-1253) Fix modal header buttons pushing the header content down
* [AUI-1248](https://issues.liferay.com/browse/AUI-1248) Allow users to request buttons to not have the .btn-default class on Bootstrap 3
* [AUI-1238](https://issues.liferay.com/browse/AUI-1238) Migrate Modal markup to Bootstrap 3

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1306](https://issues.liferay.com/browse/AUI-1306) Make aui-modal responsive
* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants
* [AUI-1107](https://issues.liferay.com/browse/AUI-1107) Listeners after visibleChange are not executed with modal.destroyOnHide enabled
